package AccessorInstaller;
use strict;
use warnings;
use parent 'Class::Accessor::Inherited::XS::Compat';

1;
